# EIDA Consistency Report: `NOA`

- Seed: `596334`
- Time: `2025-09-08T17:04:12.453700+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `16`
- Inconsistent: `4`
- Score: **80.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `4`

## Dataselect Response Types
- **NoTrace**: `3`
- **SingleTrace**: `17`

---

## Detailed Results
### `HC.RODP..HHN`
- Window: `2016-06-19T11:05:29 → 2016-06-19T11:15:29`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `1Y.GR18.00.HHE`
- Window: `2022-11-08T05:32:44 → 2022-11-08T05:42:44`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HL.PRAS..HHZ`
- Window: `2021-07-29T03:59:20 → 2021-07-29T04:09:20`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HI.PRE2..HNN`
- Window: `2013-05-30T00:31:36 → 2013-05-30T00:41:36`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `HA.THIV..HHE`
- Window: `2023-04-23T10:39:28 → 2023-04-23T10:49:28`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `1Y.GR14.00.HHZ`
- Window: `2022-12-05T00:50:01 → 2022-12-05T01:00:01`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HI.NPS1..HNN`
- Window: `2015-10-24T22:26:12 → 2015-10-24T22:36:12`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `HL.PARN2..HHE`
- Window: `2019-09-04T19:36:47 → 2019-09-04T19:46:47`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HL.GINA.00.HNZ`
- Window: `2023-11-22T02:53:09 → 2023-11-22T03:03:09`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HA.MRKA..HHN`
- Window: `2022-11-12T10:16:01 → 2022-11-12T10:26:01`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HL.LAST..HHN`
- Window: `2011-12-10T22:50:31 → 2011-12-10T23:00:31`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `1Y.GR12.00.HHN`
- Window: `2022-10-04T15:45:13 → 2022-10-04T15:55:13`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `HT.TYR1..HHZ`
- Window: `2021-03-19T16:34:58 → 2021-03-19T16:44:58`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HP.EFP..HHE`
- Window: `2023-12-14T07:30:07 → 2023-12-14T07:40:07`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HI.TRP1..HNE`
- Window: `2015-02-08T05:40:05 → 2015-02-08T05:50:05`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `HA.SNT5..HHZ`
- Window: `2025-05-03T02:39:41 → 2025-05-03T02:49:41`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `1Y.GR23.00.HHZ`
- Window: `2022-11-04T09:40:10 → 2022-11-04T09:50:10`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HL.MGNA.00.HNZ`
- Window: `2011-09-22T04:14:30 → 2011-09-22T04:24:30`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `1Y.GR20.00.HHZ`
- Window: `2022-10-18T11:12:10 → 2022-10-18T11:22:10`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `HP.PDO..HHZ`
- Window: `2010-12-25T08:01:14 → 2010-12-25T08:11:14`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`
